@@ -2,7 +2,7 @@
 https://raw.github.com/jdlrobson/ts.js/master/src/ts.js
 ***/
 //{{{
-// version 0.3.5
+// version 0.3.6
 (function() {
 var getCSRFToken = function(window) {
 	// XXX: should not use RegEx - cf.
@@ -24,7 +24,6 @@ $.ajaxSetup({
 });
 
 window.getCSRFToken = getCSRFToken;
-})(window);
 
 var ts = {
 	currentSpace: false,
@@ -107,12 +106,13 @@ var ts = {
 					window.location.href = ts.parameters.redirect ? ts.parameters.redirect : ts.getHost(status.username);
 				}
 				// do login status
+				ts.forms.password($("form.ts-password")[0]);
 				ts.loginStatus(login, register, logout);
 				if(ts.currentSpace) {
 					ts.initForSpace_();
 				}
 				if(callback) {
-					callback();
+					callback(ts);
 				}
 			}
 		});
@@ -272,6 +272,18 @@ var ts = {
 				true, { selector: "[name=space]" });
 		}
 	},
+	changePassword: function(username, password, npassword, form) {
+		var pwCallback = function() {
+			var msg = "Successfully changed your password.";
+			ts.messages.display(form, msg);
+		};
+		var pwErrback = function() {
+			var msg = "Old password is incorrect.";
+			ts.messages.display(form, msg, true, { selector: "[name=password]" });
+		};
+		var user = new tiddlyweb.User(username, password, "/");
+		user.setPassword(npassword, pwCallback, pwErrback);
+	},
 	lists: {
 		includes: function() {
 			var space = new tiddlyweb.Space(ts.currentSpace, "/");
@@ -337,6 +349,26 @@ var ts = {
 		}
 	},
 	forms: {
+		password: function(form) {
+			$(form).submit(function(ev) {
+				ev.preventDefault();
+				var oldPass = $("[name=password]").val();
+				var newPass = $("[name=new_password]").val();
+				var newPass2 = $("[name=new_password_confirm]").val();
+				if(newPass !== newPass2) {
+					var msg = "Passwords do not match";
+					ts.messages.display(form, msg, true,
+						{ selector: "[name=new_password], [name=new_password_confirm]" });
+				} else if(newPass.length < 6) {
+					var msg = "Error: password must be at least 6 characters";
+					ts.messages.display(form, msg, true, 
+						{ selector: "[name=new_password],[name=new_password_confirm]" });
+				} else {
+					ts.changePassword(ts.user.name, oldPass, newPass, form);
+				}
+				return false;
+			});
+		},
 		_csrf: function(form) {
 			$('<input type="hidden" name="csrf_token" />').val(window.getCSRFToken()).appendTo(form);
 		},
@@ -536,4 +568,10 @@ var ts = {
 		}
 	}
 };
+window.ts = {
+	init: ts.init
+};
+
+})(window);
+
 //}}}
